@@ -1,9 +1,9 @@
 /*
- *  $Id: fselect.c,v 1.106 2019/08/08 21:28:56 tom Exp $
+ *  $Id: fselect.c,v 1.111 2020/03/27 20:58:52 tom Exp $
  *
  *  fselect.c -- implements the file-selector box
  *
- *  Copyright 2000-2018,2019	Thomas E. Dickey
+ *  Copyright 2000-2019,2020	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -362,18 +362,29 @@ match(char *name, LIST * d_list, LIST * f_list, MATCH * match_list)
     size_t test_len = strlen(test);
     char **matches = dlg_malloc(char *, (size_t) (d_list->length + f_list->length));
     size_t data_len = 0;
-    int i;
-    for (i = 2; i < d_list->length; i++) {
-	if (strncmp(test, d_list->data[i], test_len) == 0) {
-	    matches[data_len++] = d_list->data[i];
+
+    if (matches != 0) {
+	int i;
+	char **new_ptr;
+
+	for (i = 2; i < d_list->length; i++) {
+	    if (strncmp(test, d_list->data[i], test_len) == 0) {
+		matches[data_len++] = d_list->data[i];
+	    }
+	}
+	for (i = 0; i < f_list->length; i++) {
+	    if (strncmp(test, f_list->data[i], test_len) == 0) {
+		matches[data_len++] = f_list->data[i];
+	    }
+	}
+	if ((new_ptr = dlg_realloc(char *, data_len + 1, matches)) != 0) {
+	    matches = new_ptr;
+	} else {
+	    free(matches);
+	    matches = 0;
+	    data_len = 0;
 	}
     }
-    for (i = 0; i < f_list->length; i++) {
-	if (strncmp(test, f_list->data[i], test_len) == 0) {
-	    matches[data_len++] = f_list->data[i];
-	}
-    }
-    matches = dlg_realloc(char *, data_len + 1, matches);
     match_list->data = matches;
     match_list->length = (int) data_len;
 }
@@ -632,10 +643,8 @@ dlg_fselect(const char *title, const char *path, int height, int width, int dsel
 #ifdef KEY_RESIZE
   retry:
 #endif
-    dlg_auto_size(title, (char *) 0, &height, &width, 6, 25);
-    height += MIN_HIGH + min_items;
-    if (width < min_wide)
-	width = min_wide;
+    dlg_auto_size(title, "", &height, &width, MIN_HIGH + min_items, min_wide);
+
     dlg_print_size(height, width);
     dlg_ctl_size(height, width);
 
@@ -871,10 +880,9 @@ dlg_fselect(const char *title, const char *path, int height, int width, int dsel
 		*current = 0;
 		resized = TRUE;
 		/* repaint */
-		dlg_clear();
-		dlg_del_window(dialog);
-		refresh();
-		dlg_mouse_free_regions();
+		free_list(&d_list, FALSE);
+		free_list(&f_list, FALSE);
+		_dlg_resize_cleanup(dialog);
 		goto retry;
 #endif
 	    default:
