@@ -1,9 +1,9 @@
 /*
- *  $Id: menubox.c,v 1.164 2019/08/08 21:00:23 tom Exp $
+ *  $Id: menubox.c,v 1.169 2020/03/27 20:53:31 tom Exp $
  *
  *  menubox.c -- implements the menu box
  *
- *  Copyright 2000-2018,2019	Thomas E. Dickey
+ *  Copyright 2000-2019,2020	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public Licens, version 2.1e
@@ -166,8 +166,18 @@ input_menu_edit(ALL_DATA * data,
 
     /* taken out of inputbox.c - but somewhat modified */
     for (;;) {
-	if (!first)
+	if (!first) {
+	    int check = DLG_EXIT_UNKNOWN;
 	    key = dlg_mouse_wgetch(data->menu, &fkey);
+	    if (dlg_result_key(key, fkey, &check)) {
+		if (check == DLG_EXIT_CANCEL) {
+		    code = FALSE;
+		    break;
+		} else {
+		    flash();
+		}
+	    }
+	}
 	if (dlg_edit_string(result, &offset, key, fkey, first)) {
 	    dlg_show_string(data->menu, result, offset, inputbox_attr,
 			    y,
@@ -341,13 +351,12 @@ dlg_menu(const char *title,
 #endif
     ALL_DATA all;
     int i, j, x, y, cur_x, cur_y;
-    int key = 0, fkey;
+    int fkey;
     int button = dialog_state.visit_items ? -1 : dlg_default_button();
     int choice = dlg_default_listitem(items);
     int result = DLG_EXIT_UNKNOWN;
     int scrollamt = 0;
     int max_choice;
-    int found;
     int use_width, name_width, text_width, list_width;
     WINDOW *dialog, *menu;
     char *prompt = 0;
@@ -363,7 +372,6 @@ dlg_menu(const char *title,
     DLG_TRACE2N("lheight", menu_height);
     DLG_TRACE2N("llength", item_no);
     /* FIXME dump the items[][] too */
-    DLG_TRACE2N("current", *current_item);
     DLG_TRACE2N("rename", rename_menutext != 0);
 
     dialog_state.plain_buttons = TRUE;
@@ -423,8 +431,7 @@ dlg_menu(const char *title,
      * After displaying the prompt, we know how much space we really have.
      * Limit the list to avoid overwriting the ok-button.
      */
-    if (all.menu_height + MIN_HIGH > height - cur_y)
-	all.menu_height = height - MIN_HIGH - cur_y;
+    all.menu_height = height - MIN_HIGH - cur_y;
     if (all.menu_height <= 0)
 	all.menu_height = 1;
 
@@ -513,7 +520,10 @@ dlg_menu(const char *title,
     dlg_draw_buttons(dialog, height - 2, 0, buttons, button, FALSE, width);
 
     dlg_trace_win(dialog);
+
     while (result == DLG_EXIT_UNKNOWN) {
+	int key, found;
+
 	if (button < 0)		/* --visit-items */
 	    wmove(dialog,
 		  all.box_y + ItemToRow(choice) + 1,
@@ -731,9 +741,7 @@ dlg_menu(const char *title,
 		resizeit(height, LINES);
 		resizeit(width, COLS);
 		free(prompt);
-		dlg_clear();
-		dlg_del_window(dialog);
-		dlg_mouse_free_regions();
+		_dlg_resize_cleanup(dialog);
 		/* repaint */
 		goto retry;
 #endif
@@ -750,6 +758,8 @@ dlg_menu(const char *title,
     free(prompt);
 
     *current_item = scrollamt + choice;
+
+    DLG_TRACE2N("current", *current_item);
     return result;
 }
 
