@@ -1,9 +1,9 @@
 /*
- *  $Id: tailbox.c,v 1.74 2019/07/24 23:46:36 tom Exp $
+ *  $Id: tailbox.c,v 1.78 2020/03/27 19:31:03 tom Exp $
  *
  *  tailbox.c -- implements the tail box
  *
- *  Copyright 2000-2018,2019	Thomas E. Dickey
+ *  Copyright 2000-2019,2020	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -263,7 +263,16 @@ handle_my_getc(DIALOG_CALLBACK * cb, int ch, int fkey, int *result)
 		obj->hscroll += 1;
 	    break;
 	default:
-	    beep();
+	    if (is_DLGK_MOUSE(ch)) {
+		*result = dlg_ok_buttoncode(ch - M_EVENT);
+		if (*result != DLG_EXIT_ERROR) {
+		    done = TRUE;
+		} else {
+		    beep();
+		}
+	    } else {
+		beep();
+	    }
 	    break;
 	}
 	if ((obj->hscroll != obj->old_hscroll))
@@ -403,7 +412,7 @@ dialog_tailbox(const char *title,
     } else {
 	int ch;
 	do {
-	    ch = dlg_getc(dialog, &fkey);
+	    ch = dlg_mouse_wgetch(dialog, &fkey);
 #ifdef KEY_RESIZE
 	    if (fkey && ch == KEY_RESIZE) {
 		dlg_will_resize(dialog);
@@ -411,10 +420,7 @@ dialog_tailbox(const char *title,
 		height = old_height;
 		width = old_width;
 		/* repaint */
-		dlg_clear();
-		dlg_del_window(dialog);
-		refresh();
-		dlg_mouse_free_regions();
+		_dlg_resize_cleanup(dialog);
 		dlg_button_layout(buttons, &min_width);
 		goto retry;
 	    }
